<?php
namespace OrganizationsManagement\Controller;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\Messages;
use OrganizationsManagement\Util\Utilities;

class LayoutExportation extends Simple
{
    /** @var Service\LayoutExportation $layoutExportation */
    protected $serviceLayoutExportation;

    public function __construct(Service\LayoutExportation $layoutExportation){
        $this->serviceLayoutExportation = $layoutExportation;
    }
    
    public function saveLayout(DTO\Request\DataSet $request, DTO\Response $response){
        $requestRow = $request->getDataSet()->getRows()[0];
        try {
            $layout = $this->serviceLayoutExportation->saveLayout($requestRow);
            $response->addDataSet(new DataSource\DataSet('layoutExportation', $layout));
            $response->addMessage(new DTO\Response\Message(Messages::SUC_SAVED));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
    
    public function removeLayout(DTO\Request\Row $request, DTO\Response $response){
        try {
            $requestRow = $request->getRow();
            $layoutId = $requestRow['ID'];
            $this->serviceLayoutExportation->removeLayout($layoutId);
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
    
    public function saveLayoutTables(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $rows = $request->getDataSet()->getRows();
            $layoutExportationTable = $this->serviceLayoutExportation->saveLayoutTables($rows);
            $response->addDataSet(new DataSource\DataSet('layoutExportationTable', $layoutExportationTable));
            $response->addMessage(new DTO\Response\Message(Messages::SUC_SAVED));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
    
    public function removeLayoutTables(DTO\Request\Row $request, DTO\Response $response){
        try {
            $row = $request->getRow();
            $this->serviceLayoutExportation->removeLayoutTables($row);
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
    
    public function getLayoutExportation(DTO\Request\Filter $request, DTO\Response $response){
        $filters = $request->getFilterCriteria()->getConditions();
        try {
            $layoutExportation = $this->serviceLayoutExportation->getLayoutExportation($filters);
            $response->addDataSet(new DataSource\DataSet('layoutExportation', $layoutExportation));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
    
    public function getTablesLayoutExportation(DTO\Request\Filter $request, DTO\Response $response){
        $filters = $request->getFilterCriteria()->getConditions();
        try {
            $layoutExportationTables = $this->serviceLayoutExportation->getTablesLayoutExportation($filters);
            $response->addDataSet(new DataSource\DataSet('layoutExportationTables', $layoutExportationTables));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
    
    public function getTables(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $page     = $request->getFilterCriteria()->getPage();
            $pageSize = $request->getFilterCriteria()->getPageSize();
            $filters  = $request->getFilterCriteria()->getConditions();
            $layoutId = Utilities::getValueInFilterDataSourceByName($filters, 'LAYOUT_ID', true);
            $tables   = $this->serviceLayoutExportation->getTables($layoutId, $page, $pageSize, $filters);
            $response->addDataSet(new DataSource\DataSet('tables', $tables));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
}