<?php
namespace OrganizationsManagement\Controller;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\Messages;
use OrganizationsManagement\Util\Utilities;

class OrgElemento extends Simple
{
    /** @var Service\OrgElemento $serviceOrgElemento */
    protected $serviceOrgElemento;

    public function __construct(Service\OrgElemento $serviceOrgElemento){
        $this->serviceOrgElemento = $serviceOrgElemento;
    }
    
    public function save(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $elementId = $requestRow['ID'];
            $parentId = $requestRow['PARENT_ID'];
            $productId = $requestRow['PROJECT_ID'];
            $elementUniqueId = $requestRow['UNIQUE_ID'];
            $elementProductOrg = $requestRow['PRODUCT_ORG'];
            $visibleOnly = (isset($requestRow['VISIBLE_ONLY']) && $requestRow['VISIBLE_ONLY']) ? true : false;
            $expirationDate = isset($requestRow['DTVALIDADE']) ? $requestRow['DTVALIDADE'] : null;
            $permanentElements = isset($requestRow['PERMANENT_ELEMENTS']) ? $requestRow['PERMANENT_ELEMENTS'] : null;
            $dsobservacao = isset($requestRow['DSOBSERVACAO']) ? $requestRow['DSOBSERVACAO'] : null;
            $this->serviceOrgElemento->save($elementId, $elementUniqueId, $elementProductOrg, $productId, $parentId, $visibleOnly, $expirationDate, $permanentElements, $dsobservacao);
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }

    public function updateElementsObservation(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $elementId = $requestRow['ID'];
            $elementProductOrg = $requestRow['PRODUCT_ORG'];
            $dsobservacao = isset($requestRow['DSOBSERVACAO']) ? $requestRow['DSOBSERVACAO'] : null;
            $dtvalidade = isset($requestRow['DTVALIDADE']) ? $requestRow['DTVALIDADE'] : null;
            $this->serviceOrgElemento->updateElementsObservation($elementId, $elementProductOrg, $dsobservacao, $dtvalidade);
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }
    
    public function updateElements(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $elements = $requestRow['ELEMENTS'];
            $dtvalidade = $requestRow['ROW']['DTVALIDADE'];
            $elementProductOrg = $requestRow['PRODUCT_ORG'];
            $dsobservacao = isset($requestRow['ROW']['DSOBSERVACAO']) ? $requestRow['ROW']['DSOBSERVACAO'] : null;
            $this->serviceOrgElemento->updateElementsObservationInArray($elements, $elementProductOrg, $dsobservacao, $dtvalidade);
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }
   
   public function getOrgElements(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $productId = Utilities::getValueInFilterDataSourceByName($filters, 'PROJECT_ID');
            $elementProductOrg = Utilities::getValueInFilterDataSourceByName($filters, 'PRODUCT_ORG');

            $response->addDataSet(new DataSource\DataSet('orgElements', $this->serviceOrgElemento->getOrgElements($productId, $elementProductOrg)));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }
    
    public function getChildrenOrgElements(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $id = Utilities::getValueInFilterDataSourceByName($filters, 'ID');
            $response->addDataSet(new DataSource\DataSet('getChildrenOrgElements', $this->serviceOrgElemento->getChildrenOrgElements($id)));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }
} 