
function FilterService (Query, ZHPromise){
    var _filterType = {};

    var _buildFilterTypeMap = function(fields) {
        fields.forEach(function(field) {
            if(field.isVisible && field.aclIsVisible){
                if (field.template && field.template.indexOf('between-dates.html') !== -1) {
                    _filterType[field.name] = "BETWEEN";
                } else if (field.template && (field.template.indexOf('number.html') !== -1 || field.template.indexOf('datetime.html') !== -1)) {
                    _filterType[field.name] = "=";
                } else if (field.outData && field.template && field.template.indexOf('select.html') !== -1) {
                    _filterType[field.outData[field.valueField]] = "=";
                } else if (field.template && field.template.indexOf('select-multiple.html') !== -1){
                    _filterType[field.name] = "IN";
                } else {
                    _filterType[field.name] = "LIKE";
                }
            }
        });
    };

    var _filterTypeFlow = {
        "BETWEEN": function(query, value) {
            query.between([value.start, value.end]);
        },
        "LIKE": function(query, value) {
            query.like('%' + value + '%');
        },
        "=": function(query, value) {
            query.equals(value);
        },
        "IN": function(query, value) {
            query.in(value);
        }
    };

    this.buildFilter = function(fields, row) {
        _buildFilterTypeMap(fields);
        var query = Query.build();
        for (var key in row) {
            if (row[key] && _filterType[key] && (!Array.isArray(row[key]) || row[key].length > 0)) {
                query.where(key);
                _filterTypeFlow[_filterType[key]](query, row[key]);
            }
        }
        return query.where();
    };

    this.parentFilter = function(parentWidget, childWidget){
        if(parentWidget && childWidget && childWidget.fields && childWidget.currentRow){
            if(!parentWidget.dataSourceFilter){
                parentWidget.dataSourceFilter = [];
                parentWidget.innerFilters = [];
            } else if(!parentWidget.innerFilters){
                parentWidget.innerFilters = parentWidget.dataSourceFilter || [];
            }
            parentWidget.dataSourceFilter = parentWidget.innerFilters.concat(this.buildFilter(childWidget.fields, childWidget.currentRow));
            return parentWidget.reload();
        } else {
            var deferred = ZHPromise.defer();
            deferred.reject("Invalid params");
            return deferred;
        }
    };

}

Configuration(function(ContextRegister) {
    ContextRegister.register('FilterService', FilterService);
});